@@ -1,13 +1,15 @@
 import unittest
 import doctest
 
-import pdfreader.buffer, pdfreader.document
+import pdfreader.buffer, pdfreader.document, pdfreader.utils
 
 
 def suite():
     loader = unittest.TestLoader()
     suite = loader.discover('.')
     suite.addTests(doctest.DocTestSuite(pdfreader.buffer))
+    suite.addTests(doctest.DocTestSuite(pdfreader.document))
+    suite.addTests(doctest.DocTestSuite(pdfreader.utils))
     return suite
 
 
